@@ -7,7 +7,7 @@ RDF::Trine::Serializer::NQuads - N-Quads Serializer
 
 =head1 VERSION
 
-This document describes RDF::Trine::Serializer::NQuads version 0.124_04
+This document describes RDF::Trine::Serializer::NQuads version 0.125_01
 
 =head1 SYNOPSIS
 
@@ -45,11 +45,12 @@ use RDF::Trine::Error qw(:try);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.124_04';
+	$VERSION	= '0.125_01';
 	$RDF::Trine::Serializer::serializer_names{ 'nquads' }	= __PACKAGE__;
-# 	foreach my $type (qw(text/plain)) {
-# 		$RDF::Trine::Serializer::media_types{ $type }	= __PACKAGE__;
-# 	}
+	$RDF::Trine::Serializer::format_uris{ 'http://sw.deri.org/2008/07/n-quads/#n-quads' }	= __PACKAGE__;
+	foreach my $type (qw(text/x-nquads)) {
+		$RDF::Trine::Serializer::media_types{ $type }	= __PACKAGE__;
+	}
 }
 
 ######################################################################
