@@ -7,7 +7,7 @@ RDF::Trine::Store - RDF triplestore base class
 
 =head1 VERSION
 
-This document describes RDF::Trine::Store version 0.124_04
+This document describes RDF::Trine::Store version 0.125_01
 
 =cut
 
@@ -31,7 +31,7 @@ use RDF::Trine::Store::SPARQL;
 
 our ($VERSION, $HAVE_REDLAND, %STORE_CLASSES);
 BEGIN {
-	$VERSION	= '0.124_04';
+	$VERSION	= '0.125_01';
 	if ($RDF::Redland::VERSION) {
 		$HAVE_REDLAND	= 1;
 	}
@@ -75,6 +75,48 @@ sub new_with_string {
 	}
 }
 
+
+=item C<< new_with_config ( $hashref ) >>
+
+Returns a new RDF::Trine::Store object based on the supplied
+configuration hashref. This requires the the Store subclass to be
+supplied with a C<storetype> key, while other keys are required by the
+Store subclasses, please refer to each subclass for specific
+documentation.
+
+An example invocation for the DBI store may be:
+
+  my $store = RDF::Trine::Store->new_with_config({
+                                                  storetype => 'DBI',
+                                                  name      => 'mymodel',
+                                                  dsn       => 'DBI:mysql:database=rdf',
+                                                  username  => 'dahut',
+                                                  password  => 'Str0ngPa55w0RD'
+                                                 });
+
+=cut
+
+
+sub new_with_config {
+  my $proto	= shift;
+  my $config	= shift;
+  if (defined($config)) {
+    my $class	= join('::', 'RDF::Trine::Store', $config->{storetype});
+    if ($class->can('_new_with_config')) {
+      return $class->_new_with_config( $config );
+    } else {
+      throw RDF::Trine::Error::UnimplementedError -text => "The class $class doesn't support the use of new_with_config";
+    }
+  } else {
+    throw RDF::Trine::Error::MethodInvocationError;
+  }
+}
+
+
+
+
+
+
 =item C<< new_with_object ( $object ) >>
 
 Returns a new RDF::Trine::Store object based on the supplied opaque C<< $object >>.
