@@ -4,7 +4,7 @@ RDF::Trine::Store::Hexastore - RDF store implemented with the hexastore index
 
 =head1 VERSION
 
-This document describes RDF::Trine::Store::Hexastore version 0.124_04
+This document describes RDF::Trine::Store::Hexastore version 0.125_01
 
 =head1 SYNOPSIS
 
@@ -43,7 +43,7 @@ use constant OTHERNODES	=> {
 
 our $VERSION;
 BEGIN {
-	$VERSION	= "0.124_04";
+	$VERSION	= "0.125_01";
 	my $class	= __PACKAGE__;
 	$RDF::Trine::Store::STORE_CLASSES{ $class }	= $VERSION;
 }
@@ -59,6 +59,47 @@ BEGIN {
 Returns a new storage object using the supplied arguments to construct a DBI
 object for the underlying database.
 
+=item C<new_with_config ( $hashref )>
+
+Returns a new storage object configured with a hashref with certain
+keys as arguments.
+
+The C<storetype> key must be C<Memory> for this backend.
+
+This module also supports initializing the store from a file or URL,
+in which case, a C<sources> key may be used. This holds an arrayref of
+hashrefs.  To load a file, you may give the file name with a C<file>
+key in the hashref, and to load a URL, use C<url>. See example
+below. Furthermore, the following keys may be used:
+
+=over
+
+=item C<syntax>
+
+The syntax of the parsed file or URL.
+
+=item C<base_uri>
+
+The base URI to be used for a parsed file.
+
+=back
+
+The following example initializes a Hexastore store based on a local file and a remote URL:
+
+  my $store = RDF::Trine::Store->new_with_config(
+                {storetype => 'Hexastore',
+		 sources => [
+			      {
+			       file => 'test-23.ttl',
+			       syntax => 'turtle',
+			      },
+			      {
+			       url => 'http://www.kjetil.kjernsmo.net/foaf',
+			       syntax => 'rdfxml',
+		      	      }
+	        ]});
+
+
 =cut
 
 sub new {
@@ -79,6 +120,29 @@ sub _new_with_string {
     return $self->load($filename);
 }
 
+# TODO: Refactor, almost identical to Memory
+sub _new_with_config {
+  my $class	= shift;
+  my $config	= shift;
+  my @sources	= @{$config->{sources}};
+  my $self	= $class->new();
+  foreach my $source (@sources) {
+    if ($source->{url}) {
+      my $parser = RDF::Trine::Parser->new($source->{syntax});
+      $parser->parse_url_into_model( $source->{url}, $self );
+    } elsif ($source->{file}) {
+      open(my $fh, "<:encoding(UTF-8)", $source->{file}) 
+	|| throw RDF::Trine::Error -text => "Couldn't open file $source->{file}";
+      my $parser = RDF::Trine::Parser->new($source->{syntax});
+      $parser->parse_file_into_model( $source->{base_uri}, $source->{file}, $self );
+    } else {
+      throw RDF::Trine::Error::MethodInvocationError -text => "$class needs a url or file argument";
+    }
+  }
+  return $self;
+}
+
+
 
 
 =item C<< store ( $filename ) >>
