@@ -4,7 +4,7 @@ RDF::Trine::Store::SPARQL - RDF Store proxy for a SPARQL endpoint
 
 =head1 VERSION
 
-This document describes RDF::Trine::Store::SPARQL version 0.124_04
+This document describes RDF::Trine::Store::SPARQL version 0.125_01
 
 =head1 SYNOPSIS
 
@@ -38,7 +38,7 @@ use RDF::Trine::Error qw(:try);
 my @pos_names;
 our $VERSION;
 BEGIN {
-	$VERSION	= "0.124_04";
+	$VERSION	= "0.125_01";
 	my $class	= __PACKAGE__;
 	$RDF::Trine::Store::STORE_CLASSES{ $class }	= $VERSION;
 	@pos_names	= qw(subject predicate object context);
@@ -55,6 +55,23 @@ BEGIN {
 Returns a new storage object that will act as a proxy for the SPARQL endpoint
 accessible via the supplied C<$url>.
 
+=item C<new_with_config ( $hashref )>
+
+Returns a new storage object configured with a hashref with certain
+keys as arguments.
+
+The C<storetype> key must be C<SPARQL> for this backend.
+
+The following key must also be used:
+
+=over
+
+=item C<url>
+
+The URL of the remote endpoint.
+
+=back
+
 =cut
 
 sub new {
@@ -76,6 +93,14 @@ sub _new_with_string {
 	return $class->new( $config );
 }
 
+sub _new_with_config {
+	my $class	= shift;
+	my $config	= shift;
+	return $class->new( $config->{url} );
+}
+
+
+
 =item C<< get_statements ( $subject, $predicate, $object [, $context] ) >>
 
 Returns a stream object of all statements matching the specified subject,
